==> recoveryimage-s_series-1.0.4.tar: www/webfile/upgrade_lang_en.js <==
﻿var upgrade_type = "Type";
var upgrade_browse = "Browsing File";
var upgrade_tftp = "Download From TFTP Server";
var upgrade_http = "Download From HTTP Server";
var upgrade_file = "Please choose a file";
var upgrade_reset = "Reset to Default";
var upgrade_tftpserver = "TFTP Server";
var upgrade_filename = "File Name";
var upgrade_httpurl = "HTTP URL";
var upgrade_upload = "Upload";
var upgrade_uploading = "Uploading...";
var upgrade_download = "Download";
var upgrade_tip1 = "The system is damaged, but the data is intact. Please upgrade to recover the system.";
var upgrade_tip2 = "The system is damaged, but we have managed to recover the data. Please upgrade to recover the system.";
var upgrade_tip3 = "The system is damaged, and the data cannot be recovered. Please upgrade to recover the system. This upgrade will reset the system to factory default.";
var upgrade_text = "It will take about 2 minutes to upgrade, please wait...";
var upgrade_imagefileerror = "Image file error";
var upgrade_downloading = "Downloading";
var upgrade_upgradeing = "Upgrading";
var upgrade_checkwait = "Validating image file. Please wait.";
var upgrade_dwonloadtext = "Downloading...";
var upgrade_upgradefailed = "Upgrading failed.Please make sure the network runs normally and check if the file exist.";
var upgrade_downloadfail = "Download failed";
var upgrade_tftpserverempty = "Please enter TFTP Server";
var upgrade_filenameempty = "Please enter File Name";
var upgrade_httpurl = "Please enter HTTP URL";

==> recoveryimage-s_series-1.0.6.tar: www/webfile/upgrade_lang_en.js <==
﻿var upgrade_type = "Type";
var upgrade_browse = "Browsing File";
var upgrade_tftp = "Download From TFTP Server";
var upgrade_http = "Download From HTTP Server";
var upgrade_file = "Please choose a file";
var upgrade_reset = "Reset to Default";
var upgrade_tftpserver = "TFTP Server";
var upgrade_filename = "File Name";
var upgrade_httpurl = "HTTP URL";
var upgrade_upload = "Upload";
var upgrade_uploading = "Uploading...";
var upgrade_download = "Download";
var upgrade_tip1 = "The system is damaged, but the data is intact. Please upgrade to recover the system.";
var upgrade_tip2 = "The system is damaged, but we have managed to recover the data. Please upgrade to recover the system.";
var upgrade_tip3 = "The system is damaged, and the data cannot be recovered. Please upgrade to recover the system. This upgrade will reset the system to factory default.";
var upgrade_text = "It will take about 2 minutes to upgrade, please wait...";
var upgrade_imagefileerror = "Image file error";
var upgrade_downloading = "Downloading";
var upgrade_upgradeing = "Upgrading";
var upgrade_checkwait = "Validating image file. Please wait.";
var upgrade_dwonloadtext = "Downloading...";
var upgrade_upgradefailed = "Upgrading failed. Please make sure the network is in good connection and check if the file exists.";
var upgrade_downloadfail = "Download failed";
var upgrade_tftpserverempty = "Please enter TFTP Server";
var upgrade_filenameempty = "Please enter File Name";
var upgrade_httpurl = "Please enter HTTP URL";
